#!/bin/bash
VER=1.1
###############################################################
# WhereAmI 1.1 by Turranius ( http://www.grandis.nu/glftpd/ ) #
###                                                         ###
# Simple script to show where you are in weektop, monthtop    #
# etc etc. Also works fine for groups.                        #
# Will also show whos in front of you, and whos after.        #
# Ment to be used in irc with the .tcl script that comes with #
# this package.                                               #
###                                                         ###
# Installation:                                               #
# Copy whereami.sh to /glftpd/bin (default).                  #
# Make it executable to the user running the bot.             #
# Edit STATSBIN below to wherever your stats command is.      #
# (see Requirements:)                                         #
#                                                             #
# Edit MBLIMIT to when you want it to convert to GB instead   #
# of MB. Looks better with 92GB instead of 94208MB I think.   #
# The number is in MB, and the default is 10240 (10GB).       #
# Set it to "" to disable (always use MB).                    #
#                                                             # 
# Copy whereami.tcl to your bots /scripts folder and add the  #
# following to your bots .conf file, at the bottom:           #
# source scripts/whereami.tcl                                 #
# Edit whereami.tcl and change the path to wheerami.sh IF you #
# did not put it in /glftpd/bin.                              #
# If you wish to change the command users type to execute it, #
# change the 'bind pub - !alup pub:alup' lines. Only the      #
# !alup needs to be changed, not the pub:alup                 #
# Rehash the bot when ready.                                  #
# If you change there, you might want to change the help text #
# It is right below the part where you should not edit in     #
# this script.                                                #
###                                                         ###
# Commands in whereami.tcl are:                               #
# Usage: !alup <username>                                     #
# !alup, !aldn = Alltime up, Alltime down.                    #
# !mnup, !mndn = Month up, Month down.                        #
# !wkup, !wkdn = Week up, Week down.                          #
# !tdup, !tddn = Today up, Today down.                        #
#                                                             #
# For groups: !galup <group>                                  #
# !galup, !galdn = Alltime up, Alltime down.                  #
# Well, all the commands for users works for groups, just add #
# a g infront of them.                                        #
#                                                             #
# Note: Run any command without any arguments for a brief     #
# description.                                                #
###                                                         ###
# Requirements:                                               #
# This script uses glFtpD Stats_v3.5 which comes with glftpd. #
# If it is not in your /glftpd/bin dir, look for whereever    #
# you unpacked glftpd.                                        #
# Just run /glftpd/bin/stats to check. If you have a different#
# version from 3.5, you might run into trouble. Let me know.  #
###############################################################
# Changelog:                                                  #
# 1.1 : Added MBLIMIT.                                        #
# 1.0 : Initial release.                                      #
###                                                         ###
# Settings:

STATSBIN=/glftpd/bin/stats
MBLIMIT="10240"


#################################################################
# No changes needed below here unless you want to change output #
#################################################################

if [ "$1" = "" ]; then
  echo "WhereAmI $VER. Use: !command <username/group>. Commands are, for users: alup,aldn,mnup,mndn,wkup,wkdn,tdup,tddn. For groups, just put a g infront of any user command, like !galup <group>"
  exit 0
fi

USERDATA="$( $STATSBIN -$2 -$3 -x 500 | cut -b 1-16,48-80 | grep -w $1 )"

if [ "$USERDATA" = "" ]; then
  echo "Nothing found for $1. Misspelled or nothing is registered for this period."
  exit 0
fi

USERPOS="$( echo $USERDATA | awk -F" " '{print $1}' | tr -d [])"

USERBEFORENR="$( expr "$USERPOS" \- "1" )"
VERIFYBEFORE="$( echo $USERBEFORENR | wc -c )"
if [ "$VERIFYBEFORE" -lt "3" ]; then
  USERBEFORENR=0$USERBEFORENR
fi

USERAFTERNR="$( expr "$USERPOS" \+ "1" )"
VERIFYAFTER="$( echo $USERAFTERNR | wc -c )"
if [ "$VERIFYAFTER" -lt "3" ]; then
  USERAFTERNR="0$USERAFTERNR"
fi

if [ "$USERPOS" = "01" ]; then
  USERBEFOREDATA="NONE"
else
  USERBEFOREDATA="$( $STATSBIN -$2 -$3 -x 500 | cut -b 1-16,48-80 | grep '\['$USERBEFORENR'\]' )"
fi

USERAFTERDATA="$( $STATSBIN -$2 -$3 -x 500 | cut -b 1-16,48-80 | grep '\['$USERAFTERNR'\]' )"
if [ "$USERAFTERDATA" = "" ]; then
  USERAFTERDATA="NONE"
fi

USERNAME="$( echo $USERDATA | awk -F" " '{print $2}' )"
USERFILES="$( echo $USERDATA | awk -F" " '{print $3}' )"
USERMEG="$( echo $USERDATA | awk -F" " '{print $4}' )"

if [ "$MBLIMIT" != "" ]; then
  USERMEG="$( echo $USERMEG | tr -d MB )"
  if [ "$USERMEG" -gt "$MBLIMIT" ]; then
    USERMEG="$( expr "$USERMEG" \/ 1024 )"
    USERMEG="$USERMEG GB"
  else
    USERMEG="$USERMEG MB"
  fi
fi

if [ "$USERBEFOREDATA" != "NONE" ]; then
  USERBEFOREPOS="$( echo $USERBEFOREDATA | awk -F" " '{print $1}' | tr -d [] )"
  USERBEFORENAME="$( echo $USERBEFOREDATA | awk -F" " '{print $2}' )"
  USERBEFOREFILES="$( echo $USERBEFOREDATA | awk -F" " '{print $3}' )"
  USERBEFOREMEG="$( echo $USERBEFOREDATA | awk -F" " '{print $4}' )"
  if [ "$MBLIMIT" != "" ]; then
    USERBEFOREMEG="$( echo $USERBEFOREMEG | tr -d MB )"
    if [ "$USERBEFOREMEG" -gt "$MBLIMIT" ]; then
      USERBEFOREMEG="$( expr "$USERBEFOREMEG" \/ 1024 )"
      USERBEFOREMEG="$USERBEFOREMEG GB"
    else
      USERBEFOREMEG="$USERBEFOREMEG MB"
    fi
  fi
fi

if [ "$USERAFTERDATA" != "NONE" ]; then
  USERAFTERPOS="$( echo $USERAFTERDATA | awk -F" " '{print $1}' | tr -d [] )" 
  USERAFTERNAME="$( echo $USERAFTERDATA | awk -F" " '{print $2}' )" 
  USERAFTERFILES="$( echo $USERAFTERDATA | awk -F" " '{print $3}' )" 
  USERAFTERMEG="$( echo $USERAFTERDATA | awk -F" " '{print $4}' )" 
  if [ "$MBLIMIT" != "" ]; then
    USERAFTERMEG="$( echo $USERAFTERMEG | tr -d MB )"
    if [ "$USERAFTERMEG" -gt "$MBLIMIT" ]; then
      USERAFTERMEG="$( expr "$USERAFTERMEG" \/ 1024 )"
      USERAFTERMEG="$USERAFTERMEG GB"
    else
      USERAFTERMEG="$USERAFTERMEG MB"
    fi
  fi
fi

if [ "$USERBEFOREDATA" = "NONE" ]; then
  if [ "$USERAFTERDATA" = "NONE" ]; then
    echo "$USERNAME is 1st and ONLY on the list with $USERFILES files and $USERMEG"
  else
    echo "$USERNAME is 1st with $USERFILES files and $USERMEG, followed by $USERAFTERNAME with $USERAFTERFILES files and $USERAFTERMEG"
  fi
else
  if [ "$USERAFTERDATA" = "NONE" ]; then
    echo "$USERNAME is last at "#"$USERPOS(Tihi) with $USERFILES"F" in $USERMEG. In front, at "#"$USERBEFOREPOS is $USERBEFORENAME with $USERBEFOREFILES"F" in $USERBEFOREMEG."
  else
    echo "Ahead of $USERNAME at "#"$USERBEFOREPOS is $USERBEFORENAME with $USERBEFOREFILES"F" and $USERBEFOREMEG. $USERNAME is "#"$USERPOS with $USERFILES"F" and $USERMEG. Behind them both at "#"$USERAFTERPOS comes $USERAFTERNAME with $USERAFTERFILES"F" and $USERAFTERMEG."
  fi
fi

exit 0